'use strict';

const { parseMultipartData, sanitizeEntity } = require('strapi-utils');

function calculateGoldenScore(GD, won, draw, lose, totalMatch) {
  let meanScore = 5.0
  let GDScore = GD/totalMatch;
  if (GD < 0 ) {
      GDScore *= -1;
  }

  let chanceToGetPointScore = (((won/totalMatch)*2) + (draw/totalMatch) - ((lose/totalMatch)*2))
  return (meanScore + GDScore + chanceToGetPointScore).toFixed(2);
}

module.exports = {
  /**
   * Update a record.
   *
   * @return {Object}
   */

  async updateMany(ctx) {
    const { team_id } = ctx.params;

    let entity;

    if (ctx.is('multipart')) {
      const { data } = parseMultipartData(ctx);

      console.log(ctx)

      entity = await strapi.query('team').model.updateMany({ team_id }, data, { $set: { upsert: true } });
    } else {
      entity = await strapi.query('team').model.update({ team_id }, ctx.request.body, { $set: { upsert: true } });
    }

    return sanitizeEntity(entity, { model: strapi.models.team });
  },

  async findByLeagueId(ctx) {
    const { league_id } = ctx.params;

    let league = await strapi.query('league').model.findOne({league_id : league_id})

    sanitizeEntity(league, { model: strapi.models.league });
    
    let entities = await strapi.query('team').model.find({ leagues_id: { $in: league._id } }).sort({'name':1})

    return sanitizeEntity(entities, { model: strapi.models.team });

  },

  async findByTeamId(ctx) {
    const { team_id } = ctx.params;
    
    console.log(team_id)

    const aggregate = [
      {$match : {
        "team_id" : Number(team_id)
      }},
      {$lookup : {
        from: 'team_statistics',
        localField: 'team_id',
        foreignField: 'team_id',
        as: 'statistic'
      }},
      {$unwind : "$statistic"}
    ]

    let entities = await strapi.query('team').model.aggregate(aggregate);

    return sanitizeEntity(entities, { model: strapi.models.team });

  }
};