import React, { useState, useEffect } from 'react';
import './Statistic.css';
import { Doughnut, Line, Radar } from 'react-chartjs-2';
import 'chartjs-plugin-datalabels';
import { Row, Col, Dropdown, DropdownButton, Container } from 'react-bootstrap';
import calculateGoldenScore from "../../utils/Score";
import axios from 'axios';

function SetLineData(team) {
  return [team.Points, team.Won, team.Drawn, team.Lost, team.GD, team.GF, team.GA]
}

function SetDoughnutData(team) {
  let score = calculateGoldenScore(team.GD, team.Won, team.Drawn, team.Lost, team.Played);

  return score;
}

function SetRadarDataHome(team) {
  try {
    return [team.statistic.goalsAvg.goalsFor.home, team.statistic.goalsAvg.goalsAgainst.home, team.statistic.matchs.loses.home, team.statistic.matchs.draws.home, team.statistic.matchs.wins.home]
  } catch (error) {
    return []
  }
}

function SetRadarDataAway(team) {
  try {
    return [team.statistic.goalsAvg.goalsFor.away, team.statistic.goalsAvg.goalsAgainst.away, team.statistic.matchs.loses.away, team.statistic.matchs.draws.away, team.statistic.matchs.wins.away]
  } catch (error) {
    return []
  }
}

function Statistic() {
  const [teams, setTeams] = useState([]);
  const [title1, setTitle1] = useState('');
  const [title2, setTitle2] = useState('');
  const [selection1, setSelection1] = useState(0);
  const [selection2, setSelection2] = useState(0);
  const [teamInfo1, setTeamInfo1] = useState({});
  const [teamInfo2, setTeamInfo2] = useState({});


  function DataRender(teamInfo) {
    let info = teamInfo.teamInfo
    if (typeof (teamInfo.teamInfo) != "undefined") {

      return (<div className="teamPic"><img src={`${teamInfo.teamInfo.logo}`} />
        <h2 className="teamNameStat">{`${teamInfo.teamInfo.name}`}</h2>
        <div className="card2">
          <h4>Team Stats: </h4>
          <p><strong>Position: </strong>{info.Position}</p>
          <p><strong>Points: </strong>{info.Points}</p>
          <p><strong>Played: </strong>{info.Played} </p>
          <p><strong>Won: </strong>{info.Won}</p>
          <p><strong>Draw: </strong>{info.Drawn}</p>
          <p><strong>Lost: </strong>{info.Lost}</p>
          <p><strong>GA: </strong>{info.GA}</p>
          <p><strong>GF: </strong>{info.GF}</p>
          <p><strong>GD: </strong>{info.GD}</p>
        </div>
      </div>);
    }

    return <div></div>

  }

  function MixedGraph(prop) {

    let nameTeam1 = '';
    let nameTeam2 = '';
    let dataTeam1 = [];
    let dataTeam2 = [];
    let scoreTeam1 = '';
    let scoreTeam2 = '';
    let team1Color = 'rgba(54, 162, 235, 0.5)';
    let team2Color = 'rgba(255, 99, 132, 0.5)'
    let HomeData1,HomeData2  = [];
    let AwayData1,AwayData2 = [];

    if (typeof (prop.team1) == "undefined" && typeof (prop.team2) == "undefined") return <div></div>;

    if (typeof (prop.team1) != "undefined") {
      let team1 = prop.team1;
      nameTeam1 = team1.name
      dataTeam1 = SetLineData(team1);
      scoreTeam1 = SetDoughnutData(team1);
      HomeData1 = SetRadarDataHome(team1);
      AwayData1 = SetRadarDataAway(team1);
    }

    if (typeof (prop.team2) != "undefined") {
      let team2 = prop.team2;
      nameTeam2 = team2.name
      dataTeam2 = SetLineData(team2);
      scoreTeam2 = SetDoughnutData(team2);
      HomeData2 = SetRadarDataHome(team2);
      AwayData2 = SetRadarDataAway(team2);
    }

    const dataLineChart = {
      labels: ['point', 'Win', 'Draw', 'Lose', 'Goal Different', 'Goal Forward', 'Goal Against'],
      datasets: [
        {
          label: nameTeam1,
          data: dataTeam1,
          backgroundColor: team1Color,
        }, {
          label: nameTeam2,
          data: dataTeam2,
          backgroundColor: team2Color,
          // Changes this dataset to become a line
        }
      ]
    }

    const dataDoughnutChart = {
      labels: [nameTeam2, nameTeam1],
      datasets: [
        {
          data: [scoreTeam2, scoreTeam1],
          backgroundColor: [team2Color, team1Color]
        }
      ]
    }

    const dataRadarChartHome = {
      labels: ['Avg Goal Forward', 'Avg Goal Against', 'Lose', 'Draw', 'Win'],
      datasets: [
        {
          label: nameTeam1,
          data: HomeData1,
          backgroundColor: team1Color,
        }, {
          label: nameTeam2,
          data: HomeData2,
          backgroundColor: team2Color,
          // Changes this dataset to become a line
        }
      ]
    }

    const dataRadarChartAway = {
      labels: ['Avg Goal Forward', 'Avg Goal Against', 'Lose', 'Draw', 'Win'],
      datasets: [
        {
          label: nameTeam1,
          data: AwayData1,
          backgroundColor: team1Color,
        }, {
          label: nameTeam2,
          data: AwayData2,
          backgroundColor: team2Color,
          // Changes this dataset to become a line
        }
      ]
    }

    return <div className="card">
      <div className="m-2">
        <h3 className="titleBarGraph">Compare Statistic</h3>
        <Line data={dataLineChart} options={{ elements: { line: { tension: 0 } }, plugins: { datalabels: { display: false } } }} />
      </div>
      <div className="m-2">
        <h3 className="titleBarGraph">Compare Score</h3>
        <Doughnut data={dataDoughnutChart} options={{ plugins: { datalabels: { display: true, color: 'white' } } }} />
      </div>
      <div className="m-2">
        <h3 className="titleBarGraph">Home Stat</h3>
        <Radar data={dataRadarChartHome} options={{ plugins: { datalabels: { display: false} } }} />
      </div>
      <div className="m-2">
        <h3 className="titleBarGraph">Away Stat</h3>
        <Radar data={dataRadarChartAway} options={{ plugins: { datalabels: { display: false} } }} />
      </div>
    </div>;
  }

  const handleSelect1 = (Key, id) => {
    setSelection1(Key);
    setTitle1(id.target.id);
  }

  const handleSelect2 = (Key, id) => {
    setSelection2(Key);
    setTitle2(id.target.id);
  }

  useEffect(() => {
    let link = `http://localhost:1337/teams`
    axios.get(link)
      .then(res => {
        setTeams(res.data)
      }).catch(err => {
        console.log(err);
      })
  }, [])

  useEffect(() => {
    let link = `http://localhost:1337/teams/team_id/${selection1}`
    axios.get(link)
      .then(res => {
        setTeamInfo1(res.data[0])
      }).catch(err => {
        console.log(err);
      })
  }, [selection1])

  useEffect(() => {
    let link = `http://localhost:1337/teams/team_id/${selection2}`
    axios.get(link)
      .then(res => {
        setTeamInfo2(res.data[0])
      }).catch(err => {
        console.log(err);
      })
  }, [selection2])

  return (
    <Container className='Stat'>
      <div className='Statistic'>
        <Row>
          <Col sm={3}>
            <div className="fixPosTeam">
            <DropdownButton  title={`${title1}`} onSelect={handleSelect1}>
              {teams.map((team) => {
                return <Dropdown.Item as="button" eventKey={`${team.team_id}`} id={`${team.name}`} >{`${team.name}`}</Dropdown.Item>
              })}
            </DropdownButton>
            <DataRender teamInfo={teamInfo1} />
            </div>
          </Col>
          <Col>
            <h1 className="versus">vs</h1>
            {/* <DoughnutScore  team1={teamInfo1} team2={teamInfo2}/> */}
            <MixedGraph team1={teamInfo1} team2={teamInfo2} />
          </Col>
          <Col sm={3}>
          <div className="fixPosTeam">
            <DropdownButton title={`${title2}`} onSelect={handleSelect2}>
              {teams.map((team) => {
                return <Dropdown.Item as="button" eventKey={`${team.team_id}`} id={`${team.name}`}>{`${team.name}`}</Dropdown.Item>
              })}
            </DropdownButton>
            <DataRender  teamInfo={teamInfo2} />
            </div>
          </Col>
        </Row>
      </div>
    </Container>

  )



}

export default Statistic;
