import React, { useState, useEffect } from 'react';
import { Row, Col, Container } from 'react-bootstrap';
import { Pie, Bar} from 'react-chartjs-2';
import './TeamInfo.css';
import calculateGoldenScore from "../../utils/Score";
import axios from 'axios'


function TeamInfo(prop) {
    const [info, setInfo] = useState({})
    const [goalsAgainst, setGoalAgainst] = useState(0);
    const [goalsFor, setGoalFor] = useState(0);
    const [statLoses, setStatLoses] = useState(0);
    const [statDraw, setStatDraw] = useState(0);
    const [statWin, setStatWin] = useState(0);
    const [score,setScore] = useState(0);

    useEffect(() => {
        let link = `http://localhost:1337/teams/team_id/${prop.match.params.id}`

        axios.get(link)
            .then(res => {
                let statistic = res.data[0].statistic;
                let info = res.data[0];
                console.log(info)
                setInfo(res.data[0]);

                setGoalAgainst(statistic.goalsAvg.goalsAgainst);
                setGoalFor(statistic.goalsAvg.goalsFor);
                setStatLoses(statistic.matchs.loses);
                setStatDraw(statistic.matchs.draws);
                setStatWin(statistic.matchs.wins);
                setScore(calculateGoldenScore(info.GD,info.Won,info.Drawn,info.Lost,info.Played))


            }).catch(err => {
                console.log(err);
            }
            );
    },
        [prop.match.params.id])

    const dataPieChart = {
        labels: ['Lost', 'Draw', 'Won'],
        datasets: [
            {
                data: [info.Lost, info.Drawn, info.Won],
                backgroundColor: [
                    'rgba(255, 85, 67, 0.8)',
                    'rgba(255, 165, 0,0.8)',
                    'rgba(60, 179, 113,0.8)'
                ]
            }
        ]
    };

    const dataMixedChart = {
        labels: ['Goal Forward', 'Goal Against', 'Lose', 'Draw', 'Win'],
        datasets: [
            {
                label: 'Home',
                data: [goalsFor.home, goalsAgainst.home, statLoses.home, statDraw.home, statWin.home],
                backgroundColor: 'rgba(54, 162, 235, 0.8)',
            },{
                label: 'Away',
                data: [goalsFor.away, goalsAgainst.away, statLoses.away, statDraw.away, statWin.away],
                backgroundColor: 'rgba(255, 99, 132, 0.7)',
                // Changes this dataset to become a line
            }
        ]
    }


    return (
        <Container>
            <Row>
                <Col className="text-left box card m-4 p-3">
                    <div className='m-4'>
                        <div className='Teams'>
                            <h1 className="teamName">{`${info.name}`}</h1>
                        </div>
                        <div className='logo'>
                            <img src={`${info.logo}`} />
                        </div>
                    </div>
                    <Row>
                        <Col className="text-left box card m-4 pl-4 p-3" sm>
                            <h4>Team Stats: </h4>
                            <p><strong>Position: </strong>{info.Position}</p>
                            <p><strong>Points: </strong>{info.Points}</p>
                            <p><strong>Played: </strong>{info.Played} </p>
                            <p><strong>Won: </strong>{info.Won}</p>
                            <p><strong>Draw: </strong>{info.Drawn}</p>
                            <p><strong>Lost: </strong>{info.Lost}</p>
                            <p><strong>GA: </strong>{info.GA}</p>
                            <p><strong>GF: </strong>{info.GF}</p>
                            <p><strong>GD: </strong>{info.GD}</p>
                        </Col>
                    </Row>
                    <Row>
                        <Col className="text-left box card m-4 pl-4 p-3" sm>
                            <h4>Team Information: </h4>
                            <p><strong>Country: </strong>{info.country}</p>
                            <p><strong>Founded: </strong>{info.founded}</p>
                            <p><strong>Venue Name: </strong>{info.venue_name}</p>
                            <p><strong>Venue Capacity: </strong>{info.venue_capacity}</p>
                            <p><strong>Venue Address: </strong>{info.venue_address}</p>
                            <p><strong>Venue City: </strong>{info.venue_city}</p>
                            <p className="p-0"><strong>Venue Surface: </strong>{info.venue_surface}</p>
                        </Col>
                    </Row>
                </Col>
                <Col className="text-Right card m-4" sm={7}>
                    <div className="m-4">
                        <h3 className="goldenScore">GOLDEN SCORE</h3>
                        <p className="score"><span className={`${score >= 5.8 ? "text-success" : "text-danger"}`}>{score}</span> / 5.80</p>
                        <h3 className="titlePieGraph">Result from {info.Played} matches</h3>
                        <Pie
                            data={dataPieChart}
                            options={{
                                title: {
                                    display: true,
                                },
                                plugins: { datalabels: { display: false} }
                            }}
                        />

                    </div>
                    <div className="m-4 ">
                    <h3 className="titleBarGraph">Home - Away Statistics</h3>
                    <Bar
                        data={dataMixedChart}
                        options={{
                            scales: {
                                yAxes: [{
                                    display: true,
                                    ticks: {
                                        beginAtZero: true,
                                    }
                                }]
                            },
                            plugins: { datalabels: { display: true, color: 'white' } }
                        }}
                    />
                    </div>
                </Col>
            </Row>
        </Container>
    )
}

export default TeamInfo;